@@ -7,6 +7,7 @@ from collections import	Counter
 #from so imoprt *
 eshost	= os.getenv("eshost", "127.0.0.1") 
 esport	= int(os.getenv("esport", 9200))
+requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
 
 config = {  
 		"settings" : {
@@ -173,7 +174,7 @@ config = {
 			"isum": {"type": "integer" , "index": "false"},
 			"md5": { "type": "text", "store": "false", "norms":"false"},
 			"toks": { "type": "keyword", "index": "false" ,"store": "false"},
-			"snts": { "type": "keyword", "index": "false" ,"store": "false"},
+			"snts": { "type": "keyword", "index": "false" },
 			"blob": { "type": "binary", "store": "false"},
 			"zlib": { "type": "binary", "store": "false"},
 			"title": { "type": "text", "analyzer": "standard"},
