@@ -20,8 +20,18 @@ def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.h
 		return 0
 
 def readline(infile, sepa=None):
-	with open(infile, 'r') as fp:
+	with open(infile, 'r', encoding='utf-8') as fp:
 		while True:
 			line = fp.readline()
 			if not line: break
-			yield line.strip().split(sepa) if sepa else line.strip()
\ No newline at end of file
+			yield line.strip().split(sepa) if sepa else line.strip()
+
+def hset_if_greater(r, key, eid, ver ): 
+	res = r.hget(key, eid)
+	try: 
+		if not res :
+			r.hset(key, eid, ver)
+		else: 
+			if int(ver) > int(res) : r.hset(key, eid, ver)
+	except Exception as e:
+		print("ex:", e, eid)
\ No newline at end of file
